Command Line Interface
----------------------

The CLI module provides command-line tools for HBAT.

Main CLI Module
---------------

.. automodule:: hbat.cli.main
   :members:
   :undoc-members:
   :show-inheritance:

Functions
~~~~~~~~~

.. autofunction:: hbat.cli.main.main